==> apo-ws-client-6.00.50.1-sources.jar: fr/univlorraine/apowsclient/creationSE/EffPrevDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EffPrevDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EffPrevDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtpEffPrev" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVrsVetEffPrev" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="codElpPorteEffPrev" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbrEffPrev" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EffPrevDTO", propOrder = {
    "codEtpEffPrev",
    "codVrsVetEffPrev",
    "codElpPorteEffPrev",
    "nbrEffPrev"
})
public class EffPrevDTO {

    @XmlElement(required = true)
    protected String codEtpEffPrev;
    @XmlElement(required = true)
    protected String codVrsVetEffPrev;
    @XmlElementRef(name = "codElpPorteEffPrev", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codElpPorteEffPrev;
    @XmlElementRef(name = "nbrEffPrev", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbrEffPrev;

    /**
     * Obtient la valeur de la propriété codEtpEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtpEffPrev() {
        return codEtpEffPrev;
    }

    /**
     * Définit la valeur de la propriété codEtpEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtpEffPrev(String value) {
        this.codEtpEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVetEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVetEffPrev() {
        return codVrsVetEffPrev;
    }

    /**
     * Définit la valeur de la propriété codVrsVetEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVetEffPrev(String value) {
        this.codVrsVetEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété codElpPorteEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodElpPorteEffPrev() {
        return codElpPorteEffPrev;
    }

    /**
     * Définit la valeur de la propriété codElpPorteEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodElpPorteEffPrev(JAXBElement<String> value) {
        this.codElpPorteEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété nbrEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbrEffPrev() {
        return nbrEffPrev;
    }

    /**
     * Définit la valeur de la propriété nbrEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbrEffPrev(JAXBElement<String> value) {
        this.nbrEffPrev = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/EffPrevDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EffPrevDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EffPrevDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtpEffPrev" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVrsVetEffPrev" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="codElpPorteEffPrev" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="nbrEffPrev" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EffPrevDTO", propOrder = {
    "codEtpEffPrev",
    "codVrsVetEffPrev",
    "codElpPorteEffPrev",
    "nbrEffPrev"
})
public class EffPrevDTO {

    @XmlElement(required = true)
    protected String codEtpEffPrev;
    @XmlElement(required = true)
    protected String codVrsVetEffPrev;
    @XmlElement(nillable = true)
    protected String codElpPorteEffPrev;
    @XmlElement(nillable = true)
    protected String nbrEffPrev;

    /**
     * Obtient la valeur de la propriété codEtpEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtpEffPrev() {
        return codEtpEffPrev;
    }

    /**
     * Définit la valeur de la propriété codEtpEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtpEffPrev(String value) {
        this.codEtpEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVetEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVetEffPrev() {
        return codVrsVetEffPrev;
    }

    /**
     * Définit la valeur de la propriété codVrsVetEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVetEffPrev(String value) {
        this.codVrsVetEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété codElpPorteEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodElpPorteEffPrev() {
        return codElpPorteEffPrev;
    }

    /**
     * Définit la valeur de la propriété codElpPorteEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodElpPorteEffPrev(String value) {
        this.codElpPorteEffPrev = value;
    }

    /**
     * Obtient la valeur de la propriété nbrEffPrev.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrEffPrev() {
        return nbrEffPrev;
    }

    /**
     * Définit la valeur de la propriété nbrEffPrev.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrEffPrev(String value) {
        this.nbrEffPrev = value;
    }

}
